<?php

namespace Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Inflightor\Util\MessagesProcedureInflightor;
use Zeedhi\Framework\DTO\Response\Error;
use Doctrine\DBAL\Connection;

class AtentimentoRequisicaoController extends \Teknisa\GER\Controllers\TeknisaCrud {

	protected $dataSourceName = "retiradainf";
	
	const STATUS_PENDENTE = 'PENDENTE';
	const STATUS_APROVADA = 'APROVADA';
	
	const REQUISICAOINF = 'REQUISICAOINF';
	
	const CHILDREN_DATASOURCENAME_PRODUTOS = 'prodretiradainf';
	const CHILDREN_DATASOURCENAME_REQUISICAO = 'requisicaoinf';

    public function __construct($crudService, $parameterBag,  $environment, $dataSourceManager, $MessagesProcedureInflightor, $entityManager) {
        $this->crudService = $crudService;
        $this->parameterBag=$parameterBag;
        $this->environment=$environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->MessagesProcedureInflightor = $MessagesProcedureInflightor;
        $this->entityManager = $entityManager;
    }
    
    private function changeStatusOfRows($rows, $status){
        foreach ($rows as $row) {
            $row['IDSITUACAO'] = $status;
        }
    }
    
    private function buildDataSetOfErrors($rows, $condition){
    
        $dataSetErrors = array();
        
        foreach($rows as $row) {
            if($row['IDSITUACAO'] !== $condition){
                array_push($dataSetErrors, "PCP00034_ATENDIMENTO_INV_OPER". "#_#" . $row['NRRETIRADAINF']);
            }
        }
        
        return $dataSetErrors;
    }
    
    public function approveAtendimentoRequisicao(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $rows = $request->getDataSet()->getRows();
        
            $dataSetErrors = $this->buildDataSetOfErrors($rows, self::STATUS_PENDENTE);
            
            if(!empty($dataSetErrors)){
    			$response->addDataSet(new DataSet("errorList", $dataSetErrors));
    			throw new \Exception("PCP00034_SEL_ATEND_DE_REQ_APROV", 1);
    		}
            
            $this->changeStatusOfRows($rows, self::STATUS_APROVADA);
    
    		parent::save($request, $response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function cancelAtendimentoRequisicao(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $rows = $request->getDataSet()->getRows();
            
            $dataSetErrors = $this->buildDataSetOfErrors($rows, self::STATUS_APROVADA);
            
            if(!empty($dataSetErrors)){
    			$response->addDataSet(new DataSet("errorList", $dataSetErrors));
    			throw new \Exception("PCP00034_SEL_ATEND_DE_REQ_PEND", 2);
    		}
            
            $this->changeStatusOfRows($rows, self::STATUS_PENDENTE);
    
    		parent::save($request, $response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function saveProduto(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $novoCodigoPK = $row['__new_code_pk'].$row['CDFILIAL'];
            $row['__new_code_pk'] = $novoCodigoPK;
            $this->dataSourceName = 'prodretiradainf';
            
    		parent::save($request, $response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    private function buildFilterCriteriaForFindChildren($columnName, $value, $dataSourceName){
        $condition =  array(
            array(
                "columnName" => $columnName,
                "operator" => "=",
                "value" => $value
            )
        );
        
        return new FilterCriteria($dataSourceName, $condition);
    }
    
    private function findByColumnCondition($columnName, $value, $dataSourceName) {
        $filterCriteria = $this->buildFilterCriteriaForFindChildren($columnName, $value, $dataSourceName);
        
        return $this->dataSourceManager->findBy($filterCriteria);
    }
    
    private function isAtendimentoRequisicaoReferred($row, $dataSourceName){
        $dataSet = $this->findByColumnCondition('NRRETIRADAINF', $row['NRRETIRADAINF'], $dataSourceName);
        
        if(sizeof($dataSet->getRows()) > 0){
            return true;
        } else {
            return false;
        }
    }
    
    private function removeChildrenProdutos($row, $dataSourceName){
        $dataSet = $this->findByColumnCondition('NRRETIRADAINF', $row['NRRETIRADAINF'], $dataSourceName);
        
        return $this->dataSourceManager->delete($dataSet);
    }
    
    public function removeAtendimentoRequisicao(DTO\Request\Row $request, DTO\Response $response) {
        $connection = $this->entityManager->getConnection();
        
        try {
            $connection->beginTransaction();
            
            $row = $request->getRow();
            
            if($row['IDSITUACAO'] === self::STATUS_APROVADA) {
                throw new \Exception("PCP00034_ATENDIMENTO_APROV", 3);
            }
            
            if($row['IDORIGEM'] === self::REQUISICAOINF) {
                throw new \Exception("PCP00034_ATENDIMENTO_DE_REQ_N_EXCLUI", 4);
            }
            
            if($this->isAtendimentoRequisicaoReferred($row, self::CHILDREN_DATASOURCENAME_REQUISICAO)) {
                throw new \Exception("PCP00034_ATENDIMENTO_REF_REQ", 5);
            }
            
            $this->removeChildrenProdutos($row, self::CHILDREN_DATASOURCENAME_PRODUTOS);
            parent::delete($request, $response);
            
            $connection->commit();
        } catch (\Exception $e){
            $connection->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
}