<?php

namespace Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Inflightor\Util\MessagesProcedureInflightor;
use Zeedhi\Framework\DTO\Response\Error;
use Doctrine\DBAL\Connection;

class GeracaoPrevisaoController extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceName = "prevpaxprod";
    protected $dataSourceNameToSave = "";
    
    public function __construct($crudService, $parameterBag,  $environment, $dataSourceManager, $MessagesProcedureInflightor, $GerarPrevisaoProcedure, $GerarPrevisaoProcedureCia, $CalcularQuantidadePaxProcedure, $entityManager) {
        $this->crudService = $crudService;
        $this->parameterBag=$parameterBag;
        $this->environment=$environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->MessagesProcedureInflightor = $MessagesProcedureInflightor;
        $this->GerarPrevisaoProcedure = $GerarPrevisaoProcedure;
        $this->GerarPrevisaoProcedureCia = $GerarPrevisaoProcedureCia;
        $this->CalcularQuantidadePaxProcedure = $CalcularQuantidadePaxProcedure;
        $this->entityManager = $entityManager;
    }

    public function executeProcedureGeraPrevisao(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        $connection = $this->entityManager->getConnection();
        try {
            $connection->beginTransaction();
            $row['P_CDOPERADOR'] = $this->environment->getCdOperador();
            $row['P_NRORG'] = $this->environment->getNrOrgTrab();
            if(isset($row['BYCIA'])){
                $resultado = $this->GerarPrevisaoProcedureCia->executeProcedure($row['P_CDFILIAL'], $row['P_CDFILIPROC'], $row['P_NRPREVISAOPROD'], $row['P_CDCIA'], $row['P_CDOPERADOR'], $row['P_NRORG']);  
            } else {
                $resultado = $this->GerarPrevisaoProcedure->executeProcedure($row['P_CDFILIAL'], $row['P_CDFILIPROC'], $row['P_DATAINI'], $row['P_DATAFIN'], $row['P_SUBSTITUI_JA_GERADOS'], $row['P_CDOPERADOR'], $row['P_NRORG']);
            }
            if($resultado['P_NRLISTAERROS'] != null) {
                $this->MessagesProcedureInflightor->getErrorMessages($row['P_CDFILIPROC'], $resultado['P_NRLISTAERROS'], $response);
                $connection->rollback();
                return;
            }
            $connection->commit();
        } catch (\Exception $e){
            $connection->rollback();
            $response->setError(new Error($this->MessagesProcedureInflightor->cleanMessage($e->getMessage()), 500));
        }
    }

    public function executeProcedureCalcularPax(DTO\Request\DataSet $request, DTO\Response $response){
        $rows = $request->getDataSet()->getRows();
        $connection = $this->entityManager->getConnection();
        try {
            $connection->beginTransaction();
            $arrayErrorMsg = array();
            foreach ($rows as $row) {
                $row['P_CDOPERADOR'] = $this->environment->getCdOperador();
                $row['P_NRORG'] = $this->environment->getNrOrgTrab();
                $resultado = $this->CalcularQuantidadePaxProcedure->executeProcedure($row['P_CDFILIAL'], $row['P_CDFILIPROC'], $row['P_NRPREVISAOPROD'], $row['P_CDCIA'], $row['P_NRVOO'], $row['P_CDTRECHO'], $row['P_CDEQUIP'], $row['P_IDPADRAOCALC'], $row['P_NRPADRAOGERPREVPAX'], $row['P_CDOPERADOR'], $row['P_NRORG']);  
                if($resultado['P_NRLISTAERROS'] != null) {
                    array_merge($arrayErrorMsg, $this->MessagesProcedureInflightor->concatErrorMessages($row['P_CDFILIPROC'], $resultado['P_NRLISTAERROS'], $response, null, false));
                }
            }
            $response->addDataset(new DataSet('ListaErros', $arrayErrorMsg));
            $connection->commit();
        } catch (\Exception $e){
            $connection->rollback();
            $response->setError(new Error($this->MessagesProcedureInflightor->cleanMessage($e->getMessage()), 500));
        }
    }
}